@@ -11,6 +11,8 @@ enum class SettingsRegister : uint8_t {
     DISCONNECT_EVENT,
     MAC = 0xb,
     BATTERY_STATE = 0xc,
-    WHITELIST_FILTER_MODE = 0x13,
-    WHITELIST_ADDRESSES = 0x14
+    POWER_STATUS = 0x11,
+    CHARGE_STATUS,
+    WHITELIST_FILTER_MODE,
+    WHITELIST_ADDRESSES
 };
