@@ -76,7 +76,7 @@ static MblMwDataProcessor* find_processor(MblMwDataProcessor* processor, DataPro
     return nullptr;
 }
 
-static int64_t extract_accounter_epoch(MblMwDataProcessor* processor, const uint8_t** start, uint8_t& len, uint32_t* tick) {
+static int64_t extract_accounter_epoch(MblMwDataProcessor* processor, int64_t original_epoch, const uint8_t** start, uint8_t& len, uint32_t* tick) {
     uint8_t timestampLength = get_accounter_length(processor);
     // TODO: The logger uses a hardcoded prescaler of 3, upstream we force that value
     // and assume it to be so here, eventually we will have a prescale aware timestamp
@@ -86,7 +86,11 @@ static int64_t extract_accounter_epoch(MblMwDataProcessor* processor, const uint
     (*start) += timestampLength;
     len -= timestampLength;
 
-    return calculate_epoch(processor->owner, *tick);
+    if (get_accounter_type(processor) == ACCOUNTER_TIME) {
+        return calculate_epoch(processor->owner, *tick);
+    }
+
+    return original_epoch;
 }
 
 static bool invoke_signal_handler(MblMwDataSignal* signal, int64_t epoch, const uint8_t* response, uint8_t len, void* extra) {
@@ -118,7 +122,7 @@ static int32_t forward_response(const ResponseHeader& header, MblMwMetaWearBoard
     if (processor != nullptr) {
         switch(processor->type) {
             case DataProcessorType::ACCOUNTER: {
-                epoch = extract_accounter_epoch(processor, &start, len, &extra);
+                epoch = extract_accounter_epoch(processor, epoch, &start, len, &extra);
                 auto parent = find_processor(processor, DataProcessorType::PACKER);
 
                 if (parent != nullptr) {
@@ -138,7 +142,7 @@ static int32_t forward_response(const ResponseHeader& header, MblMwMetaWearBoard
                         pack_size = get_packer_length(processor) - (parent == nullptr ? 0 : get_accounter_length(parent));
                 
                 do {
-                    int64_t real_epoch = parent == nullptr ? epoch : extract_accounter_epoch(parent, &start, len, &extra);
+                    int64_t real_epoch = parent == nullptr ? epoch : extract_accounter_epoch(parent, epoch, &start, len, &extra);
                     handled|= invoke_signal_handler(signal, real_epoch, start, pack_size, &extra);
                     i++;
                     len-= pack_size;
@@ -268,6 +272,7 @@ const vector<tuple<MblMwGattChar, void(*)(MblMwMetaWearBoard*, const uint8_t*, u
             free_accelerometer_module(board);
             free_gyro_module(board);
             free_sensor_fusion_module(board);
+            free_settings_module(board);
 
             for (auto it : board->module_events) {
                 it.second->remove = false;
@@ -316,6 +321,7 @@ MblMwMetaWearBoard::~MblMwMetaWearBoard() {
     free_accelerometer_module(this);
     free_gyro_module(this);
     free_sensor_fusion_module(this);
+    free_settings_module(this);
 
     for (auto it: module_events) {
         it.second->remove= false;
